@@ -6,4 +6,10 @@ class AutoMapperColumns(AutoMapperContainer):
     def __init__(self, **kwargs: AutoMapperAnyDataType) -> None:
         super().__init__()
 
-        self.generate_mappers(mappers_dict=kwargs)
+        self.generate_mappers(
+            mappers_dict=kwargs,
+            column_schema={},
+            include_null_properties=False,
+            skip_schema_validation=[],
+            skip_if_columns_null_or_empty=None
+        )
