@@ -39,7 +39,7 @@ class AutoMapperDataTypeComplexBase(AutoMapperDataTypeBase):
             )
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         valid_columns = self.get_child_mappers()
         column_spec: Column = struct(
