@@ -57,7 +57,7 @@ class AutoMapperIfDataType(
         )
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         if isinstance(self.check, list):
             column_spec = when(
