@@ -17,7 +17,7 @@ class AutoMapperNumberDataType(AutoMapperDataTypeBase):
             else AutoMapperValueParser.parse_value(value)
 
     def get_column_spec(
-        self, source_df: DataFrame, current_column: Optional[Column]
+        self, source_df: Optional[DataFrame], current_column: Optional[Column]
     ) -> Column:
         if isinstance(self.value, AutoMapperDataTypeLiteral) \
                 and isinstance(self.value.value, str):
@@ -26,7 +26,7 @@ class AutoMapperNumberDataType(AutoMapperDataTypeBase):
                 source_df=source_df, current_column=current_column
             ).cast("int")
             return column_spec
-        if isinstance(self.value, AutoMapperDataTypeColumn) \
+        if source_df is not None and isinstance(self.value, AutoMapperDataTypeColumn) \
                 and dict(source_df.dtypes)[self.value.value] == "string":
             # parse the amount here
             column_spec = self.value.get_column_spec(
